set more off

capture log close
log using diGiovanni_Levchenko_Comovement_AEJmacro_TableA5, text replace

/*
    Date: July 13, 2009
    
    Program: this file reproduces Table A5 of di Giovanni and Levchenko, 
             "Putting the Parts Together: Trade, Vertical Linkages, and 
             Business Cycle Comovement", AEJ: Macro.
         
             Specification 1: pooled ij & ii
         
             Specification 2: polled with same/diff't sector split (no IO)

             Specification 3: pooled with IO.

             Specification 4: pooled with IO*ii/ij interaction
*/

clear

set mem 10g
set matsize 10000

use ../Data/indx_data_corrij_final

* Keep correlations with observations greater than 9 in calculations.

keep if obs_12>9

* Create country and sector pair codes

ge pid_ifs = ifscode1*1000+ifscode2

ge pid_isic = isiccode1*1000+isiccode2 if isiccode1<=isiccode2
replace pid_isic = isiccode1+isiccode2*1000 if isiccode1>isiccode2

ge ssec = 0
replace ssec = 1 if isiccode1 == isiccode2

* Note: cs1 = u_1*d_i, cs2 = u_2*d_j

/* 
    Program for table1 regressions:
        `1': LHS variables
        `2': country 1's export ratio
        `3': country 2's export ratio
        ltrade: sum of `2' & `4'
*/

capture program drop reg_table1_r
program define reg_table1_r
    ge ltrade = `2'+`3'
     
    * Pooled
    
    reg `1' ltrade, robust 
    outreg using `1'_`2'_tableA5_1, append coef 10pct bdec(8) tdec(8) rdec(3) se nolabel ctitle("Pooled")
            
    * Country and sector fixed effects
    
    xi: areg `1' ltrade i.ifscode2 i.isiccode1 i.isiccode2, abs(ifscode1) robust 
    outreg ltrade  using `1'_`2'_tableA5_1, append coef 10pct bdec(8) tdec(8) rdec(3) se nolabel ctitle("IFS+ISIC")

    * Country-sector1 and Country-sector2 fixed effects
    
    xi: areg `1' ltrade i.cs2, abs(cs1) robust 
    outreg ltrade  using `1'_`2'_tableA5_1, append coef 10pct bdec(8) tdec(8) rdec(3) se nolabel ctitle("IFS*ISIC")

    * Country-pair and sector-pair fixed effects
    
    xi: areg `1' ltrade i.pid_isic, abs(pid_ifs) robust 
    outreg ltrade  using `1'_`2'_tableA5_1, append coef 10pct bdec(8) tdec(8) rdec(3) se nolabel ctitle("IFS^2+ISIC^2")

    drop ltrade
end


/* 
    Program for table1 regressions:
        `1': LHS variables
        `2': country 1's export ratio
        `3': country 2's export ratio
        ltrade: sum of `2' & `4'
        ss_ltrade: ssec*ltrade
*/

capture program drop reg_table2_r
program define reg_table2_r
    ge ltrade = `2'+`3'
    ge ss_ltrade = ssec*ltrade
     
    * Pooled
    
    reg `1' ltrade ss_ltrade ssec, robust 
    outreg using `1'_`2'_tableA5_2, append coef 10pct bdec(8) tdec(8) rdec(3) se nolabel ctitle("Pooled")
            
    * Country and sector fixed effects
    
    xi: areg `1' ltrade ss_ltrade ssec i.ifscode2 i.isiccode1 i.isiccode2, abs(ifscode1) robust 
    outreg ltrade ss_ltrade ssec using `1'_`2'_tableA5_2, append coef 10pct bdec(8) tdec(8) rdec(3) se nolabel  ctitle("IFS+ISIC")
    
    * Country-sector1 and Country-sector2 fixed effects
    
    xi: areg `1' ltrade ss_ltrade ssec i.cs2, abs(cs1) robust 
    outreg ltrade ss_ltrade ssec using `1'_`2'_tableA5_2, append coef 10pct bdec(8) tdec(8) rdec(3) se nolabel  ctitle("IFS*ISIC")

    * Country-pair and sector-pair fixed effects
    
    xi: areg `1' ltrade ss_ltrade i.pid_isic, abs(pid_ifs) robust 
    outreg ltrade ss_ltrade using `1'_`2'_tableA5_2, append coef 10pct bdec(8) tdec(8) rdec(3) se nolabel  ctitle("IFS^2+ISIC^2")
        
    drop ltrade
    drop ss_ltrade
end


/* 
    Program for table3 regressions:
        `1': LHS variables
        `2': country 1's export ratio
        `3': country 2's export ratio
        `4': country 1's io
        `5': country 2's io
        ltrade: sum of `2' & `3'
        io: sum `4' & `5'
        ltrade_io: `2'*`4' + `3'*`5'
*/


capture program drop reg_table3_r
program define reg_table3_r
    ge ltrade = `2'+`3'
    ge io = `4'+`5'
    ge ltrade_io = `2'*`4'+`3'*`5'

    * Pooled
    
    reg `1' ltrade ltrade_io io, robust 
    outreg using `1'_`2'_tableA5_3, append coef 10pct bdec(8) tdec(8) rdec(3) se nolabel ctitle("Pooled")
            
    * Country and sector fixed effects
    
    xi: areg `1' ltrade ltrade_io io i.ifscode2 i.isiccode1 i.isiccode2, abs(ifscode1) robust 
    outreg ltrade ltrade_io io using `1'_`2'_tableA5_3, append coef 10pct bdec(8) tdec(8) rdec(3) se nolabel  ctitle("IFS+ISIC")

    * Country-sector1 and Country-sector2 fixed effects
    
    xi: areg `1' ltrade ltrade_io io i.cs2, abs(cs1) robust 
    outreg ltrade ltrade_io io using `1'_`2'_tableA5_3, append coef 10pct bdec(8) tdec(8) rdec(3) se nolabel ctitle("IFS*ISIC")
    
    * Country-pair and sector-pair fixed effects
    
    xi: areg `1' ltrade ltrade_io i.pid_isic, abs(pid_ifs) robust 
    outreg ltrade ltrade_io using `1'_`2'_tableA5_3, append coef 10pct bdec(8) tdec(8) rdec(3) se nolabel  ctitle("IFS^2+ISIC^2")
    
    drop ltrade
    drop io
    drop ltrade_io
end


/* 
    Program for table4 regressions:
        `1': LHS variables
        `2': country 1's export ratio
        `3': country 2's export ratio
        `4': country 1's io
        `5': country 2's io
        ltrade: sum of `2' & `3'
        io: sum `4' & `5'
        ltrade_io: `2'*`4' + `3'*`5'
        ss_ltrade: ssec*ltrade
        ss_ltrade_io: (`2'*`4' + `3'*`5')*ssec
*/

capture program drop reg_table4_r
program define reg_table4_r
    sum `1' `2' `3' `4' `5'
    ge ltrade = `2'+`3'
    ge io = `4'+`5'
    ge ltrade_io = `2'*`4'+`3'*`5'
    ge ss_ltrade = ssec*ltrade
    ge ss_io = ssec*io
    ge ss_ltrade_io = (`2'*`4' + `3'*`5')*ssec

    * Pooled
    
    reg `1' ltrade ss_ltrade ltrade_io ss_io ss_ltrade_io ssec io, robust 
    outreg using `1'_`2'_tableA5_4, append coef 10pct bdec(8) tdec(8) rdec(3) se nolabel  ctitle("Pooled")
            
    * Country and sector fixed effects
    
    xi: areg `1' ltrade ss_ltrade ltrade_io ss_io ss_ltrade_io ssec io i.ifscode2 i.isiccode1 i.isiccode2, abs(ifscode1) robust 
    outreg ltrade ss_ltrade ltrade_io ss_io ss_ltrade_io ssec io using `1'_`2'_tableA5_4, append coef 10pct bdec(8) tdec(8) rdec(3) se nolabel  ctitle("IFS+ISIC")

    * Country-sector1 and Country-sector2 fixed effects
    
    xi: areg `1' ltrade ss_ltrade  ltrade_io ss_io ss_ltrade_io ssec io  i.cs2, abs(cs1) robust 
    outreg ltrade ss_ltrade ltrade_io ss_io ss_ltrade_io ssec io using `1'_`2'_tableA5_4, append coef 10pct bdec(8) tdec(8) rdec(3) se nolabel  ctitle("IFS*ISIC")
    
    * Country-pair and sector-pair fixed effects
    
    xi: areg `1' ltrade ss_ltrade ltrade_io ss_io ss_ltrade_io i.pid_isic, abs(pid_ifs) robust 
    outreg ltrade ss_ltrade ltrade_io ss_io ss_ltrade_io using `1'_`2'_tableA5_4, append coef 10pct bdec(8) tdec(8) rdec(3) se nolabel  ctitle("IFS^2+ISIC^2")
    
    drop ltrade
    drop io
    drop ss_ltrade
    drop ltrade_io ss_io
    drop ss_ltrade_io
end

* Define local variables to feed into regressions

local LHS "hp_corr_12"
local RHS "lbiexports_gdp"
local IOvars "IO_USA"

* Initialize outreg files so that can simply add on afterwords, so ignore first column

local FEfiles "tableA5_1 tableA5_2 tableA5_3 tableA5_4"

quietly foreach X of local LHS{
    foreach Y of local FEfiles{
        foreach Z of local RHS{
            reg ifscode1 ifscode2
            outreg using `X'_`Z'1_`Y', replace coef 10pct bdec(8) tdec(8) rdec(3) se nolabel 
        }   
    }
}
 
* Table 1

foreach Y of local LHS{
    foreach X of local RHS{
        foreach Z of local IOvars{
            reg_table1_r `Y' `X'1 `X'2 `Z'1 `Z'2
        }
    }
}

* Table 2

foreach Y of local LHS{
    foreach X of local RHS{
        foreach Z of local IOvars{
            reg_table2_r `Y' `X'1 `X'2 `Z'1 `Z'2
        }
    }
}

* Table 3

foreach Y of local LHS{
    foreach X of local RHS{
        foreach Z of local IOvars{
            reg_table3_r `Y' `X'1 `X'2 `Z'1 `Z'2
        }
    }
}
 
* Table 4

foreach Y of local LHS{
    foreach X of local RHS{
        foreach Z of local IOvars{
            reg_table4_r `Y' `X'1 `X'2 `Z'1 `Z'2
        }
    }
}

log close 
