set more off

capture log close
log using diGiovanni_Levchenko_Comovement_AEJmacro_TablesB4_B8, text replace

/*
    Date: July 13, 2009
    
    Program: this file reproduces Tables B4-8 of di Giovanni and Levchenko, 
             "Putting the Parts Together: Trade, Vertical Linkages, and 
             Business Cycle Comovement", AEJ: Macro.
             Note that within-R2 calculated in a seperate .do file:
                diGiovanni_Levchenko_Comovement_AEJmacro_TablesB4_B8_R2.do
        
             Regression Table 1: pooled ij & ii
         
             Regression Table 2: polled with same/diff't sector split (no IO)

             Regression Table 3: pooled with IO.

             Regression Table 4: pooled with IO*ii/ij interaction

             Regression Table 5: IO and Luong & BW elasticity
*/

clear

set mem 10g
set matsize 10000

use ../Data/indx_data_corrij_final

tsset, clear

* Keep correlations with observations greater than 9 in calculations.

keep if obs_12>9

* Will trim 2.5% of sample (1.25% on each side).

local def "gdp secexports totexports"
foreach X of local def{
    ge trade = biexports_`X'1 + biexports_`X'2
    egen biexports_`X'1_p = pctile(trade), p(1.25)
    egen biexports_`X'2_p = pctile(trade), p(98.75)
    drop trade
}

* For output deflated variable, will trim 5% of sample (2.5% on each side).

local def "output"
foreach X of local def{
    ge trade = biexports_`X'1 + biexports_`X'2
    egen biexports_`X'1_p = pctile(trade), p(2.5)
    egen biexports_`X'2_p = pctile(trade), p(97.5)
    drop trade
}

* Create country and sector pair codes

ge pid_ifs = ifscode1*1000+ifscode2

ge pid_isic = isiccode1*1000+isiccode2 if isiccode1<=isiccode2
replace pid_isic = isiccode1+isiccode2*1000 if isiccode1>isiccode2

ge ssec = 0
replace ssec = 1 if isiccode1 == isiccode2

* Note: cs1 = u_1*d_i, cs2 = u_2*d_j

/* 
    Program for table1 regressions:
        `1': LHS variables
        `2': country 1's export ratio
        `3': country 2's export ratio
        trade: sum of `2' & `4'
*/

capture program drop reg_table1
program define reg_table1
    ge trade = `2'+`3'
     
    * Pooled
    
    reg `1' trade if trade>`2'_p & trade<`3'_p, robust 
    outreg using `1'_`2'_tableB4, append coef 10pct bdec(4) rdec(3) se nolabel ctitle("Pooled")
            
    * Country and sector fixed effects
    
    xi: areg `1' trade i.ifscode2 i.isiccode1 i.isiccode2 if trade>`2'_p & trade<`3'_p, abs(ifscode1) robust   
    outreg trade  using `1'_`2'_tableB4, append coef 10pct bdec(4) rdec(3) se nolabel ctitle("IFS+ISIC") 

    * Country-sector1 and Country-sector2 fixed effects
    
    xi: areg `1' trade i.cs2 if trade>`2'_p & trade<`3'_p, abs(cs1) robust 
    outreg trade  using `1'_`2'_tableB4, append coef 10pct bdec(4) rdec(3) se nolabel ctitle("IFS*ISIC") 

    * Country-pair and sector-pair fixed effects
    
    xi: areg `1' trade i.pid_isic if trade>`2'_p & trade<`3'_p, abs(pid_ifs) robust 
    outreg trade  using `1'_`2'_tableB4, append coef 10pct bdec(4) rdec(3) se nolabel ctitle("IFS^2+ISIC^2") 

    drop trade
end


/* 
    Program for table2 regressions:
        `1': LHS variables
        `2': country 1's export ratio
        `3': country 2's export ratio
        trade: sum of `2' & `4'
        ss_trade: ssec*trade
*/

capture program drop reg_table2
program define reg_table2
    ge trade = `2'+`3'
    ge ss_trade = ssec*trade
     
    * Pooled
    
    reg `1' trade ss_trade ssec if trade>`2'_p & trade<`3'_p, robust 
    lincom trade+ss_trade
    local b = r(estimate)
    local se = r(se)
    outreg using `1'_`2'_tableB5, append coef 10pct bdec(4) rdec(3) se nolabel addstat("b_sum",`b',"se_sum",`se') adec(4) ctitle("Pooled")
            
    * Country and sector fixed effects
    
    xi: areg `1' trade ss_trade ssec i.ifscode2 i.isiccode1 i.isiccode2 if trade>`2'_p & trade<`3'_p, abs(ifscode1) robust 
    lincom trade+ss_trade
    local b = r(estimate)
    local se = r(se)
    outreg trade ss_trade ssec using `1'_`2'_tableB5, append coef 10pct bdec(4) rdec(3) se nolabel addstat("b_sum",`b',"se_sum",`se') adec(4) ctitle("IFS+ISIC")
    
    * Country-sector1 and Country-sector2 fixed effects
    
    xi: areg `1' trade ss_trade ssec i.cs2 if trade>`2'_p & trade<`3'_p, abs(cs1) robust 
    lincom trade+ss_trade
    local b = r(estimate)
    local se = r(se) 
    outreg trade ss_trade ssec using `1'_`2'_tableB5, append coef 10pct bdec(4) rdec(3) se nolabel addstat("b_sum",`b',"se_sum",`se') adec(4) ctitle("IFS*ISIC")

    * Country-pair and sector-pair fixed effects
    
    xi: areg `1' trade ss_trade i.pid_isic if trade>`2'_p & trade<`3'_p, abs(pid_ifs) robust 
    lincom trade+ss_trade
    local b = r(estimate)
    local se = r(se)
    outreg trade ss_trade using `1'_`2'_tableB5, append coef 10pct bdec(4) rdec(3) se nolabel addstat("b_sum",`b',"se_sum",`se') adec(4) ctitle("IFS^2+ISIC^2")
        
    drop trade
    drop ss_trade
end


/* 
    Program for table3 regressions:
        `1': LHS variables
        `2': country 1's export ratio
        `3': country 2's export ratio
        `4': country 1's io
        `5': country 2's io
        trade: sum of `2' & `3'
        io: sum `4' & `5'
        trade_io: `2'*`4' + `3'*`5'
*/


capture program drop reg_table3
program define reg_table3
    ge trade = `2'+`3'
    ge io = `4'+`5'
    ge trade_io = `2'*`4'+`3'*`5'

    * Pooled
    
    reg `1' trade trade_io io if trade>`2'_p & trade<`3'_p, robust 
    outreg using `1'_`2'_tableB6, append coef 10pct bdec(4) rdec(3) se nolabel ctitle("Pooled")
            
    * Country and sector fixed effects
    
    xi: areg `1' trade trade_io io i.ifscode2 i.isiccode1 i.isiccode2 if trade>`2'_p & trade<`3'_p, abs(ifscode1) robust 
    outreg trade trade_io io using `1'_`2'_tableB6, append coef 10pct bdec(4) rdec(3) se nolabel  ctitle("IFS+ISIC") 

    * Country-sector1 and Country-sector2 fixed effects
    
    xi: areg `1' trade trade_io io i.cs2 if trade>`2'_p & trade<`3'_p, abs(cs1) robust 
    outreg trade trade_io io using `1'_`2'_tableB6, append coef 10pct bdec(4) rdec(3) se nolabel ctitle("IFS*ISIC") 
    
    * Country-pair and sector-pair fixed effects
    
    xi: areg `1' trade trade_io i.pid_isic if trade>`2'_p & trade<`3'_p, abs(pid_ifs) robust  
    outreg trade trade_io using `1'_`2'_tableB6, append coef 10pct bdec(4) rdec(3) se nolabel  ctitle("IFS^2+ISIC^2") 
    
    drop trade
    drop io
    drop trade_io
end


/* 
    Program for table4 regressions:
        `1': LHS variables
        `2': country 1's export ratio
        `3': country 2's export ratio
        `4': country 1's io
        `5': country 2's io
        trade: sum of `2' & `3'
        io: sum `4' & `5'
        trade_io: `2'*`4' + `3'*`5'
        ss_trade: ssec*trade
        ss_trade_io: (`2'*`4' + `3'*`5')*ssec
*/

capture program drop reg_table4
program define reg_table4
    sum `1' `2' `3' `4' `5'
    ge trade = `2'+`3'
    ge io = `4'+`5'
    ge trade_io = `2'*`4'+`3'*`5'
    ge ss_trade = ssec*trade
    ge ss_io = ssec*io
    ge ss_trade_io = (`2'*`4' + `3'*`5')*ssec

    * Pooled
    
    reg `1' trade ss_trade trade_io ss_io ss_trade_io ssec io if trade>`2'_p & trade<`3'_p, robust 
    lincom trade+ss_trade
    local b = r(estimate)
    local se = r(se)
    outreg using `1'_`2'_tableB7, append coef 10pct bdec(4) rdec(3) se nolabel addstat("b_sum",`b',"se_sum",`se') adec(4) ctitle("Pooled")
            
    * Country and sector fixed effects
    
    xi: areg `1' trade ss_trade trade_io ss_io ss_trade_io ssec io i.ifscode2 i.isiccode1 i.isiccode2 if trade>`2'_p & trade<`3'_p, abs(ifscode1) robust 
    lincom trade+ss_trade
    local b = r(estimate)
    local se = r(se)
    outreg trade ss_trade trade_io ss_io ss_trade_io ssec io using `1'_`2'_tableB7, append coef 10pct bdec(4) rdec(3) se nolabel addstat("b_sum",`b',"se_sum",`se') adec(4) ctitle("IFS+ISIC")

    * Country-sector1 and Country-sector2 fixed effects
    
    xi: areg `1' trade ss_trade  trade_io ss_io ss_trade_io ssec io  i.cs2 if trade>`2'_p & trade<`3'_p, abs(cs1) robust 
    lincom trade+ss_trade
    local b = r(estimate)
    local se = r(se)
    outreg trade ss_trade trade_io ss_io ss_trade_io ssec io using `1'_`2'_tableB7, append coef 10pct bdec(4) rdec(3) se nolabel addstat("b_sum",`b',"se_sum",`se') adec(4) ctitle("IFS*ISIC")
    
    * Country-pair and sector-pair fixed effects
    
    xi: areg `1' trade ss_trade trade_io ss_io ss_trade_io i.pid_isic if trade>`2'_p & trade<`3'_p, abs(pid_ifs) robust 
    lincom trade+ss_trade
    local b = r(estimate)
    local se = r(se)
    outreg trade ss_trade trade_io ss_io ss_trade_io using `1'_`2'_tableB7, append coef 10pct bdec(4) rdec(3) se nolabel addstat("b_sum",`b',"se_sum",`se') adec(4) ctitle("IFS^2+ISIC^2")
    
    drop trade
    drop io
    drop ss_trade
    drop trade_io ss_io
    drop ss_trade_io
end


/* 
    Program for table5 regressions:
        `1': LHS variables
        `2': country 1's export ratio
        `3': country 2's export ratio
        `4': country 1's io
        `5': country 2's io
      `6': country 1's elasticity
      `7': country 2's elasticity
        trade: sum of `2' & `3'
        io: sum `4' & `5'
      elasticity: sum of `6' & `7'
        trade_io: `2'*`4' + `3'*`5'
        trade_elas:  `2'*`7' + `3'*`6'
*/

capture program drop reg_table5
program define reg_table5
    ge trade = `2'+`3'
    ge io = `4'+`5'
    ge elasticity = `6'+`7'
    ge trade_io = `2'*`4' + `3'*`5'
    ge trade_elast = `2'*`7' + `3'*`6'

    * Pooled
    
    reg `1' trade trade_io trade_elast io elasticity if trade>`2'_p & trade<`3'_p, robust 
    outreg using `1'_`2'_tableB8, append coef 10pct bdec(4) rdec(3) se nolabel ctitle("Pooled")
            
    * Country and sector fixed effects
    
    xi: areg `1' trade trade_io trade_elast io elasticity i.ifscode2 i.isiccode1 i.isiccode2 if trade>`2'_p & trade<`3'_p, abs(ifscode1) robust 
    outreg trade trade_io trade_elast io elasticity using `1'_`2'_tableB8, append coef 10pct bdec(4) rdec(3) se nolabel  ctitle("IFS+ISIC") 

    * Country-sector1 and Country-sector2 fixed effects
    
    xi: areg `1' trade trade_io trade_elast io elasticity i.cs2 if trade>`2'_p & trade<`3'_p, abs(cs1) robust 
    outreg trade trade_io trade_elast io elasticity using `1'_`2'_tableB8, append coef 10pct bdec(4) rdec(3) se nolabel ctitle("IFS*ISIC") 
    
    * Country-pair and sector-pair fixed effects
    
    xi: areg `1' trade trade_io trade_elast  i.pid_isic if trade>`2'_p & trade<`3'_p, abs(pid_ifs) robust 
    outreg trade trade_io trade_elast using `1'_`2'_tableB8, append coef 10pct bdec(4) rdec(3) se nolabel  ctitle("IFS^2+ISIC^2") 
    
    drop trade
    drop io
    drop trade_io
    drop elasticity
    drop trade_elast
end

/*****************************/


* Define local variables to feed into regressions

local LHS "corr_12"
local RHS "biexports_gdp biexports_output biexports_secexports biexports_totexports"
local FEfiles "tableB4 tableB5 tableB6 tableB7 tableB8"
local IOvars "IO_USA"
local ELAST "elasticity_luong elasticity_bw"


* Initialize outreg files so that can simply add on afterwords, so ignore first column

quietly foreach X of local LHS{
    foreach Y of local FEfiles{
        foreach Z of local RHS{
            reg ifscode1 ifscode2
            outreg using `X'_`Z'1_`Y', replace coef 10pct bdec(4) rdec(3) se nolabel 
        }   
    }
}
 
* Table B4

foreach Y of local LHS{
    foreach X of local RHS{
        foreach Z of local IOvars{
            reg_table1 `Y' `X'1 `X'2 `Z'1 `Z'2
        }
    }
}

* Table B5

foreach Y of local LHS{
    foreach X of local RHS{
        foreach Z of local IOvars{
            reg_table2 `Y' `X'1 `X'2 `Z'1 `Z'2
        }
    }
}

* Table B6

foreach Y of local LHS{
    foreach X of local RHS{
        foreach Z of local IOvars{
            reg_table3 `Y' `X'1 `X'2 `Z'1 `Z'2
        }
    }
}
 
* Table B7

foreach Y of local LHS{
    foreach X of local RHS{
        foreach Z of local IOvars{
            reg_table4 `Y' `X'1 `X'2 `Z'1 `Z'2
        }
    }
}

* Table B8

foreach Y of local LHS{
    foreach X of local RHS{
        foreach Z of local IOvars{
            foreach Q of local ELAST{
                reg_table5 `Y' `X'1 `X'2 `Z'1 `Z'2 `Q'1 `Q'2
            }
        }
    }
}

log close 
