set more off

capture log close
log using diGiovanni_Levchenko_Comovement_AEJmacro_TablesB4_B8_R2, text replace

/*
    Date: July 13, 2009
    
    Program: this file reproduces the within-R2 of Tables B4-8 of di Giovanni and Levchenko, 
             "Putting the Parts Together: Trade, Vertical Linkages, and 
             Business Cycle Comovement", AEJ: Macro.
         
             Regression Table 1: pooled ij & ii
         
             Regression Table 2: polled with same/diff't sector split (no IO)

             Regression Table 3: pooled with IO.

             Regression Table 4: pooled with IO*ii/ij interaction

             Regression Table 5: IO and Luong & BW elasticity
*/

clear

set mem 10g
set matsize 10000

use ../Data/indx_data_corrij_final

tsset, clear

* Keep correlations with observations greater than 9 in calculations.

keep if obs_12>9

* Will trim 2.5% of sample (1.25% on each side).

local def "gdp secexports totexports"
foreach X of local def{
    ge trade = biexports_`X'1 + biexports_`X'2
    egen biexports_`X'1_p = pctile(trade), p(1.25)
    egen biexports_`X'2_p = pctile(trade), p(98.75)
    drop trade
}

* Will trim 5% of sample (2.5% on each side).

local def "output"
foreach X of local def{
    ge trade = biexports_`X'1 + biexports_`X'2
    egen biexports_`X'1_p = pctile(trade), p(2.5)
    egen biexports_`X'2_p = pctile(trade), p(97.5)
    drop trade
}

* Create country and sector pair codes

ge pid_ifs = ifscode1*1000+ifscode2

ge pid_isic = isiccode1*1000+isiccode2 if isiccode1<=isiccode2
replace pid_isic = isiccode1+isiccode2*1000 if isiccode1>isiccode2

ge ssec = 0
replace ssec = 1 if isiccode1 == isiccode2

* Note: cs1 = u_1*d_i, cs2 = u_2*d_j

/*
   Program for  RSS of main regression
*/

capture program drop rss_n
program define rss_n
    mat rss = e(rss)
    svmat rss
    egen rss_n = mean(rss1)
    local rss_n = rss_n
    mat rss_n = `rss_n'
    drop rss1 rss_n
end
 
/*
   Program for  RSS of dummy regression
*/

capture program drop rss_d
program define rss_d
    mat rss = e(rss)
    svmat rss
    egen rss_d = mean(rss1)
    local rss_d = rss_d
    mat rss_d = `rss_d'
    drop rss1 rss_d
end

/* 
    Program for table1 regressions:
        `1': LHS variables
        `2': country 1's export ratio
        `3': country 2's export ratio
        trade: sum of `2' & `4'
*/

capture program drop reg_table1
program define reg_table1
    ge trade = `2'+`3'

    mat R2_`2'_1 = J(1,3,.)
                     
    * Country and sector fixed effects
    
    xi: areg `1' trade i.ifscode2 i.isiccode1 i.isiccode2 if trade>`2'_p & trade<`3'_p, abs(ifscode1) 
    rss_n
    xi: areg `1' i.ifscode2 i.isiccode1 i.isiccode2 if e(sample), abs(ifscode1) 
    rss_d
    mat R2_`2'_1[1,1] = 1 - rss_n[1,1]/rss_d[1,1]
    

    * Country-sector1 and Country-sector2 fixed effects
    
    xi: areg `1' trade i.cs1 if trade>`2'_p & trade<`3'_p, abs(cs2) 
    rss_n
    xi: areg `1' i.cs1 if e(sample), abs(cs2) 
    rss_d
    mat R2_`2'_1[1,2] = 1 - rss_n[1,1]/rss_d[1,1]

    * Country-pair and sector-pair fixed effects
    
    xi: areg `1' trade i.pid_isic if trade>`2'_p & trade<`3'_p, abs(pid_ifs) 
    rss_n
    xi: areg `1' i.pid_isic if e(sample), abs(pid_ifs) 
    rss_d
    mat R2_`2'_1[1,3] = 1 - rss_n[1,1]/rss_d[1,1]

    drop trade
end


/* 
    Program for table2 regressions:
        `1': LHS variables
        `2': country 1's export ratio
        `3': country 2's export ratio
        trade: sum of `2' & `4'
        ss_trade: ssec*trade
*/

capture program drop reg_table2
program define reg_table2
    ge trade = `2'+`3'
    ge ss_trade = ssec*trade
     
    mat R2_`2'_2 = J(1,3,.)
                     
    * Country and sector fixed effects
    
    xi: areg `1' trade ss_trade ssec i.ifscode2 i.isiccode1 i.isiccode2 if trade>`2'_p & trade<`3'_p, abs(ifscode1) 
    rss_n
    xi: areg `1' i.ifscode2 i.isiccode1 i.isiccode2 if e(sample), abs(ifscode1) 
    rss_d
    mat R2_`2'_2[1,1] = 1 - rss_n[1,1]/rss_d[1,1]
    

    * Country-sector1 and Country-sector2 fixed effects
    
    xi: areg `1' trade ss_trade ssec i.cs1 if trade>`2'_p & trade<`3'_p, abs(cs2) 
    rss_n
    xi: areg `1' i.cs1 if e(sample), abs(cs2) 
    rss_d
    mat R2_`2'_2[1,2] = 1 - rss_n[1,1]/rss_d[1,1]

    * Country-pair and sector-pair fixed effects
    
    xi: areg `1' trade ss_trade i.pid_isic if trade>`2'_p & trade<`3'_p, abs(pid_ifs) 
    rss_n
    xi: areg `1' i.pid_isic if e(sample), abs(pid_ifs) 
    rss_d
    mat R2_`2'_2[1,3] = 1 - rss_n[1,1]/rss_d[1,1]
                        
    drop trade
    drop ss_trade
end


/* 
    Program for table3 regressions:
        `1': LHS variables
        `2': country 1's export ratio
        `3': country 2's export ratio
        `4': country 1's io
        `5': country 2's io
        trade: sum of `2' & `3'
        io: sum `4' & `5'
        trade_io: `2'*`4' + `3'*`5'
*/


capture program drop reg_table3
program define reg_table3
    ge trade = `2'+`3'
    ge io = `4'+`5'
    ge trade_io = `2'*`4'+`3'*`5'

    mat R2_`2'_3 = J(1,3,.)
                     
    * Country and sector fixed effects
    
    xi: areg `1' trade trade_io io i.ifscode2 i.isiccode1 i.isiccode2 if trade>`2'_p & trade<`3'_p, abs(ifscode1) 
    rss_n
    xi: areg `1' i.ifscode2 i.isiccode1 i.isiccode2 if e(sample), abs(ifscode1) 
    rss_d
    mat R2_`2'_3[1,1] = 1 - rss_n[1,1]/rss_d[1,1]
    

    * Country-sector1 and Country-sector2 fixed effects
    
    xi: areg `1' trade trade_io io i.cs1 if trade>`2'_p & trade<`3'_p, abs(cs2) 
    rss_n
    xi: areg `1' i.cs1 if e(sample), abs(cs2) 
    rss_d
    mat R2_`2'_3[1,2] = 1 - rss_n[1,1]/rss_d[1,1]

    * Country-pair and sector-pair fixed effects
    
    xi: areg `1' trade trade_io i.pid_isic if trade>`2'_p & trade<`3'_p, abs(pid_ifs) 
    rss_n
    xi: areg `1' i.pid_isic if e(sample), abs(pid_ifs) 
    rss_d
    mat R2_`2'_3[1,3] = 1 - rss_n[1,1]/rss_d[1,1]
        
    drop trade
    drop io
    drop trade_io
end


/* 
    Program for table4 regressions:
        `1': LHS variables
        `2': country 1's export ratio
        `3': country 2's export ratio
        `4': country 1's io
        `5': country 2's io
        trade: sum of `2' & `3'
        io: sum `4' & `5'
        trade_io: `2'*`4' + `3'*`5'
        ss_trade: ssec*trade
        ss_trade_io: (`2'*`4' + `3'*`5')*ssec
*/

capture program drop reg_table4
program define reg_table4
    sum `1' `2' `3' `4' `5'
    ge trade = `2'+`3'
    ge io = `4'+`5'
    ge trade_io = `2'*`4'+`3'*`5'
    ge ss_trade = ssec*trade
    ge ss_io = ssec*io
    ge ss_trade_io = (`2'*`4' + `3'*`5')*ssec

    mat R2_`2'_4 = J(1,3,.)
                     
    * Country and sector fixed effects
    
    xi: areg `1' trade ss_trade trade_io ss_io ss_trade_io ssec io i.ifscode2 i.isiccode1 i.isiccode2 if trade>`2'_p & trade<`3'_p, abs(ifscode1) 
    rss_n
    xi: areg `1' i.ifscode2 i.isiccode1 i.isiccode2 if e(sample), abs(ifscode1) 
    rss_d
    mat R2_`2'_4[1,1] = 1 - rss_n[1,1]/rss_d[1,1]
    

    * Country-sector1 and Country-sector2 fixed effects
    
    xi: areg `1' trade ss_trade trade_io ss_io ss_trade_io ssec io i.cs1 if trade>`2'_p & trade<`3'_p, abs(cs2) 
    rss_n
    xi: areg `1' i.cs1 if e(sample), abs(cs2) 
    rss_d
    mat R2_`2'_4[1,2] = 1 - rss_n[1,1]/rss_d[1,1]

    * Country-pair and sector-pair fixed effects
    
    xi: areg `1' trade ss_trade trade_io ss_io ss_trade_io  i.pid_isic if trade>`2'_p & trade<`3'_p, abs(pid_ifs) 
    rss_n
    xi: areg `1' i.pid_isic if e(sample), abs(pid_ifs) 
    rss_d
    mat R2_`2'_4[1,3] = 1 - rss_n[1,1]/rss_d[1,1]
                
    drop trade
    drop io
    drop ss_trade
    drop trade_io ss_io
    drop ss_trade_io
end


/* 
    Program for table5 regressions:
        `1': LHS variables
        `2': country 1's export ratio
        `3': country 2's export ratio
        `4': country 1's io
        `5': country 2's io
        `6': country 1's elasticity
        `7': country 2's elasticity
        trade: sum of `2' & `3'
        io: sum `4' & `5'
        elasticity: sum of `6' & `7'
        trade_io: `2'*`4' + `3'*`5'
        trade_elas:  `2'*`7' + `3'*`6'
*/

capture program drop reg_table5
program define reg_table5
    ge trade = `2'+`3'
    ge io = `4'+`5'
    ge elasticity = `6'+`7'
    ge trade_io = `2'*`4' + `3'*`5'
    ge trade_elast = `2'*`7' + `3'*`6'

    mat R2_`2'_5 = J(1,3,.)
                     
    * Country and sector fixed effects
    
    xi: areg `1' trade trade_io trade_elast io elasticity i.ifscode2 i.isiccode1 i.isiccode2 if trade>`2'_p & trade<`3'_p, abs(ifscode1) 
    rss_n
    xi: areg `1' i.ifscode2 i.isiccode1 i.isiccode2 if e(sample), abs(ifscode1) 
    rss_d
    mat R2_`2'_5[1,1] = 1 - rss_n[1,1]/rss_d[1,1]
    

    * Country-sector1 and Country-sector2 fixed effects
    
    xi: areg `1' trade trade_io trade_elast io elasticity i.cs1 if trade>`2'_p & trade<`3'_p, abs(cs2) 
    rss_n
    xi: areg `1' i.cs1 if e(sample), abs(cs2) 
    rss_d
    mat R2_`2'_5[1,2] = 1 - rss_n[1,1]/rss_d[1,1]

    * Country-pair and sector-pair fixed effects
    
    xi: areg `1' trade trade_io trade_elast i.pid_isic if trade>`2'_p & trade<`3'_p, abs(pid_ifs) 
    rss_n
    xi: areg `1' i.pid_isic if e(sample), abs(pid_ifs) 
    rss_d
    mat R2_`2'_5[1,3] = 1 - rss_n[1,1]/rss_d[1,1]
                
    drop trade
    drop io
    drop trade_io
    drop elasticity
    drop trade_elast
end

/*****************************/


* Define local variables to feed into regressions

local LHS "corr_12"
local RHS "biexports_gdp biexports_output biexports_secexports biexports_totexports"
local FEfiles "table1 table2 table3 table4 table5"
local IOvars "IO_USA"


* Table B4

mat R2_1 = J(4,3,.)
foreach Y of local LHS{
    foreach X of local RHS{
        foreach Z of local IOvars{
            reg_table1 `Y' `X'1 `X'2 `Z'1 `Z'2
        }
    }
}
mat R2_1[1,1] = R2_biexports_gdp1_1
mat R2_1[2,1] = R2_biexports_output1_1
mat R2_1[3,1] = R2_biexports_secexports1_1
mat R2_1[4,1] = R2_biexports_totexports1_1

svmat R2_1
outsheet R2_1* using TableB4_R2, replace

* Table B5

mat R2_2 = J(4,3,.)
foreach Y of local LHS{
    foreach X of local RHS{
        foreach Z of local IOvars{
            reg_table2 `Y' `X'1 `X'2 `Z'1 `Z'2
        }
    }
}

mat R2_2[1,1] = R2_biexports_gdp1_2
mat R2_2[2,1] = R2_biexports_output1_2
mat R2_2[3,1] = R2_biexports_secexports1_2
mat R2_2[4,1] = R2_biexports_totexports1_2

svmat R2_2
outsheet R2_2* using TableB5_R2, replace

* Table B6

mat R2_3 = J(4,3,.)
foreach Y of local LHS{
    foreach X of local RHS{
        foreach Z of local IOvars{
            reg_table3 `Y' `X'1 `X'2 `Z'1 `Z'2
        }
    }
}

mat R2_3[1,1] = R2_biexports_gdp1_3
mat R2_3[2,1] = R2_biexports_output1_3
mat R2_3[3,1] = R2_biexports_secexports1_3
mat R2_3[4,1] = R2_biexports_totexports1_3

svmat R2_3
outsheet R2_3* using TableB6_R2, replace

 
* Table B7

mat R2_4 = J(4,3,.)
foreach Y of local LHS{
    foreach X of local RHS{
        foreach Z of local IOvars{
            reg_table4 `Y' `X'1 `X'2 `Z'1 `Z'2
        }
    }
}

mat R2_4[1,1] = R2_biexports_gdp1_4
mat R2_4[2,1] = R2_biexports_output1_4
mat R2_4[3,1] = R2_biexports_secexports1_4
mat R2_4[4,1] = R2_biexports_totexports1_4

svmat R2_4
outsheet R2_4* using TableB7_R2, replace


* Table B8 - BW

local ELAST "elasticity_bw"

mat R2_5 = J(4,3,.)
foreach Y of local LHS{
    foreach X of local RHS{
        foreach Z of local IOvars{
            foreach Q of local ELAST{
                reg_table5 `Y' `X'1 `X'2 `Z'1 `Z'2 `Q'1 `Q'2
            }
        }
    }
}

mat R2_5[1,1] = R2_biexports_gdp1_5
mat R2_5[2,1] = R2_biexports_output1_5
mat R2_5[3,1] = R2_biexports_secexports1_5
mat R2_5[4,1] = R2_biexports_totexports1_5

svmat R2_5
outsheet R2_5* using TableB8_R2_BW, replace

* Table B8 - Luong

local ELAST "elasticity_luong"

mat R2_5 = J(4,3,.)
foreach Y of local LHS{
    foreach X of local RHS{
        foreach Z of local IOvars{
            foreach Q of local ELAST{
                reg_table5 `Y' `X'1 `X'2 `Z'1 `Z'2 `Q'1 `Q'2
            }
        }
    }
}

mat R2_5[1,1] = R2_biexports_gdp1_5
mat R2_5[2,1] = R2_biexports_output1_5
mat R2_5[3,1] = R2_biexports_secexports1_5
mat R2_5[4,1] = R2_biexports_totexports1_5

svmat R2_5, names(R2_6)
outsheet R2_6* using TableB8_R2_Luong, replace

log close 
